@@ -28,7 +28,7 @@ Moose::Exporter->setup_import_methods(
     as_is => [qw/get_options/],
 );
 
-our $VERSION = version->new('0.3.2');
+our $VERSION = version->new('0.3.3');
 our $EXIT    = 1;
 
 has options => (
@@ -363,7 +363,7 @@ sub process {
             $self->_show_help(1);
         }
         elsif ( $self->auto_complete && $self->opt->auto_complete ) {
-            if ( $ARGV[-1] =~ /^-/xms ) {
+            if ( $ARGV[-1] && $ARGV[-1] =~ /^-/xms ) {
                 print join ' ', $self->list_options;
             }
             else {
@@ -483,7 +483,7 @@ Getopt::Alt - Command line option passing with with lots of features
 
 =head1 VERSION
 
-This documentation refers to Getopt::Alt version 0.3.2.
+This documentation refers to Getopt::Alt version 0.3.3.
 
 =head1 SYNOPSIS
 
